Stan Math Library: stan/math/prim/mat/fun/size.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
size.hpp File Reference
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
int | stan::math::size (const std::vector< T > &x)
| Return the size of the specified standard vector. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.